abacusai.holdout_analysis_version — AbacusAI documentation

# abacusai.holdout_analysis_version

## Classes

`HoldoutAnalysisVersion` | A holdout analysis version object.

## Module Contents

class abacusai.holdout_analysis_version.HoldoutAnalysisVersion(client, holdoutAnalysisVersion=None, holdoutAnalysisId=None, createdAt=None, status=None, error=None, modelId=None, modelVersion=None, algorithm=None, algoName=None, metrics=None, metricInfos=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A holdout analysis version object.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - holdoutAnalysisVersion (str) – The unique identifier of the holdout analysis version.

    - holdoutAnalysisId (str) – The unique identifier of the holdout analysis.

    - createdAt (str) – The timestamp at which the holdout analysis version was created.

    - status (str) – The status of the holdout analysis version.

    - error (str) – The error message if the status is FAILED.

    - modelId (str) – The model id associated with the holdout analysis.

    - modelVersion (str) – The model version associated with the holdout analysis.

    - algorithm (str) – The algorithm used to train the model.

    - algoName (str) – The name of the algorithm used to train the model.

    - metrics (dict) – The metrics of the holdout analysis version.

    - metricInfos (dict) – The metric infos of the holdout analysis version.

  holdout_analysis_version = None
  holdout_analysis_id = None
  created_at = None
  status = None
  error = None
  model_id = None
  model_version = None
  algorithm = None
  algo_name = None
  metrics = None
  metric_infos = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      HoldoutAnalysisVersion

  describe(get_metrics=False)

    Get a holdout analysis version.

    Parameters:

      get_metrics (bool) – (optional) Whether to get the metrics for the holdout analysis version

    Returns:

      The holdout analysis version

    Return type:

      HoldoutAnalysisVersion

  wait_for_results(timeout=3600)

    A waiting call until holdout analysis for the version is complete

    Parameters:

      timeout (int) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the holdout analysis version.

    Returns:

      A string describing the status of a holdout analysis version (pending, complete, etc.).

    Return type:

      str